@@ -12,7 +12,7 @@ use XML::LibXML::XPathContext;
 use Data::Validate::URI qw(is_web_uri);
 use Scalar::Util qw(blessed);
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 with 'Catmandu::Importer';
 
@@ -299,6 +299,11 @@ sub _hashify {
 
     $out->{count} = $xc->findvalue("/result/count");
 
+    if ( $self->fullResponse ) {
+        $out->{results} = [$root];
+        return $out;
+    }
+
     my @result_nodes;
 
     if ( $xc->exists('/result/items') ) {
@@ -309,11 +314,6 @@ sub _hashify {
         @result_nodes = $xc->findnodes('/result/*[@uuid]');
     };
 
-    if ( $self->fullResponse ) {
-        $out->{results} = [$root];
-        return $out;
-    }
-
     $out->{results} = \@result_nodes;
 
     return $out;
@@ -391,7 +391,7 @@ sub generator {
       . '  <workflowStep>validated</workflowStep>'
       . '</workflowSteps>'
       . '</researchOutputsQuery>'
-  )->first->{result}[0]{count};
+  )->first->{count};
 
 =head1 DESCRIPTION
 
@@ -488,7 +488,7 @@ user input. Note that there is a small performance penalty when using this optio
 =item filter( sub {} )
 
 Optional reference to function that processes the XML response before it is parsed. The argument to the function is a reference to the XML text,
-which is then used to modify it. This is option is normally not needed but can helpful if there is a problem parsing the response due to a bug
+which is then used to modify it. This option is normally not needed but can helpful if there is a problem parsing the response due to a bug
 in the REST service.
 
 =back
